@@ -8,20 +8,12 @@ class Py42Response(object):
     def __init__(self, requests_response):
         self._response = requests_response
         self._data_root = None
-        try:
-            response_dict = json.loads(self._response.text)
-            if type(response_dict) == dict:
-                self._data_root = response_dict.get(u"data") or response_dict
-            else:
-                self._data_root = response_dict
-        except ValueError:
-            self._data_root = self._response.text or u""
 
     def __getitem__(self, key):
         try:
-            return self._data_root[key]
+            return self._data[key]
         except TypeError as e:
-            data_root_type = type(self._data_root)
+            data_root_type = type(self._data)
             message = u"The Py42Response root is of type {0}, but __getitem__ got a key of {1}, which is incompatible.".format(
                 data_root_type, key
             )
@@ -29,7 +21,7 @@ class Py42Response(object):
 
     def __setitem__(self, key, value):
         try:
-            self._data_root[key] = value
+            self._data[key] = value
         except TypeError as e:
             data_root_type = type(self._data_root)
             message = u"The Py42Response root is of type {0}, but __setitem__ got a key of {1} and value of {2}, which is incompatible.".format(
@@ -39,7 +31,7 @@ class Py42Response(object):
 
     def __iter__(self):
         # looping over a Py42Response will loop through list items, dict keys, or str characters
-        return iter(self._data_root)
+        return iter(self._data)
 
     @property
     def encoding(self):
@@ -75,7 +67,7 @@ class Py42Response(object):
     @property
     def text(self):
         """The more useful parts of the HTTP response dumped into a dictionary."""
-        return json.dumps(self._data_root) if type(self._data_root) != str else self._data_root
+        return json.dumps(self._data) if type(self._data) != str else self._data
 
     @property
     def url(self):
@@ -88,10 +80,24 @@ class Py42Response(object):
         return self._response.status_code
 
     def __str__(self):
-        return str(self._data_root)
+        return str(self._data)
 
     def __repr__(self):
-        data = self._data_root
+        data = self._data
         return u"<{} [status={}, data={}]>".format(
             self.__class__.__name__, self._response.status_code, reprlib.repr(data)
         )
+
+    @property
+    def _data(self):
+        try:
+            if not self._data_root:
+                response_dict = json.loads(self._response.text)
+                if type(response_dict) == dict:
+                    self._data_root = response_dict.get(u"data") or response_dict
+                else:
+                    self._data_root = response_dict
+        except ValueError:
+            self._data_root = self._response.text or u""
+
+        return self._data_root
